searchData={"items":[{"type":"module","title":"OpenApiTypesense.Plugins.Field","doc":"Provides the Field struct that is used by the renderer\n\nThis struct is created by the Processor to hold only the data necessary for rendering fields\nand their types. It has the following fields:\n\n  * `name`: Name of the field in its parent schema\n  * `nullable`: Whether the field is defined as nullable\n  * `private`: Whether the field was added via the `output.extra_fields` configuration\n  * `required`: Whether the field is marked as required by its parent schema\n  * `type`: Internal representation of the field's type\n  * `default`: Default value provided by yaml openapi spec","ref":"OpenApiTypesense.Plugins.Field.html"},{"type":"type","title":"OpenApiTypesense.Plugins.Field.t/0","doc":"Processed field data used by the renderer","ref":"OpenApiTypesense.Plugins.Field.html#t:t/0"},{"type":"behaviour","title":"OpenApiTypesense.Client","doc":"Http client for Typesense server.","ref":"OpenApiTypesense.Client.html"},{"type":"function","title":"OpenApiTypesense.Client.api_key/0","doc":"Returns the Typesense's API key\n\n> #### Warning {: .warning}\n>\n> Even if `api_key` is hidden in `Connection` struct, this\n> function will still return the key and accessible inside\n> shell (assuming bad actors [pun unintended `:/`] can get in as well).","ref":"OpenApiTypesense.Client.html#api_key/0"},{"type":"function","title":"OpenApiTypesense.Client.build_req_client/2","doc":"","ref":"OpenApiTypesense.Client.html#build_req_client/2"},{"type":"function","title":"OpenApiTypesense.Client.request/1","doc":"Command for making http requests.\n\n> #### On using this function {: .info}\n> Functions e.g. `OpenApiTypesense.Health.health` don't need to explicitly pass\n> a `connection` unless you want to use custom `connection`. See\n> [`README`](/README.md) for more details or `OpenApiTypesense.Connection` module.","ref":"OpenApiTypesense.Client.html#request/1"},{"type":"function","title":"Options - OpenApiTypesense.Client.request/1","doc":"- `:body`: Payload for passing as request body (defaults to `nil`).\n- `:url`: Request path.\n- `:method`: Request method (e.g. `:get`, `:post`, `:put`, `:patch`, `:delete`). Defaults to `:get`.\n- `:query`: Request query params (defaults to `%{}`).","ref":"OpenApiTypesense.Client.html#request/1-options"},{"type":"function","title":"Examples - OpenApiTypesense.Client.request/1","doc":"iex> connection = %OpenApiTypesense.Connection{\n    ...>   host: \"localhost\",\n    ...>   api_key: \"some_api_key\",\n    ...>   port: \"8108\",\n    ...>   scheme: \"http\"\n    ...> }\n    iex> opts = %{\n    ...>   url: \"/health\",\n    ...>   method: :get\n    ...> }\n    iex> Client.request(connection, opts)\n    {:ok, %OpenApiTypesense.HealthStatus{ok: true}}","ref":"OpenApiTypesense.Client.html#request/1-examples"},{"type":"callback","title":"OpenApiTypesense.Client.request/1","doc":"A callback function for custom HTTP client","ref":"OpenApiTypesense.Client.html#c:request/1"},{"type":"type","title":"OpenApiTypesense.Client.response/0","doc":"","ref":"OpenApiTypesense.Client.html#t:response/0"},{"type":"module","title":"OpenApiTypesense.Connection","doc":"Fetches credentials either from application env or map.","ref":"OpenApiTypesense.Connection.html"},{"type":"function","title":"OpenApiTypesense.Connection.config/0","doc":"","ref":"OpenApiTypesense.Connection.html#config/0"},{"type":"function","title":"OpenApiTypesense.Connection.config/2","doc":"","ref":"OpenApiTypesense.Connection.html#config/2"},{"type":"function","title":"OpenApiTypesense.Connection.new/0","doc":"Setting new connection or using the default config.\n\n> #### On using this function {: .info}\n> Functions e.g. `OpenApiTypesense.Health.health/0` don't need to explicitly pass this\n> unless you want to use another connection. Also, `api_key` is hidden when invoking\n> this function.","ref":"OpenApiTypesense.Connection.html#new/0"},{"type":"function","title":"Examples - OpenApiTypesense.Connection.new/0","doc":"iex> alias OpenApiTypesense.Connection\n    ...> Connection.new()\n    %OpenApiTypesense.Connection{\n      host: \"localhost\",\n      port: 8108,\n      scheme: \"http\",\n      api_key: \"xyz\"\n    }\n\n    iex> alias OpenApiTypesense.Connection\n    ...> Connection.new(%{})\n    ** (ArgumentError) Missing required fields: [:api_key, :host, :port, :scheme]","ref":"OpenApiTypesense.Connection.html#new/0-examples"},{"type":"function","title":"OpenApiTypesense.Connection.new/1","doc":"","ref":"OpenApiTypesense.Connection.html#new/1"},{"type":"type","title":"OpenApiTypesense.Connection.t/0","doc":"","ref":"OpenApiTypesense.Connection.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.Analytics","doc":"Provides API endpoints related to analytics","ref":"OpenApiTypesense.Analytics.html"},{"type":"function","title":"OpenApiTypesense.Analytics.create_analytics_event/2","doc":"Create an analytics event\n\nSending events for analytics e.g rank search results based on popularity.","ref":"OpenApiTypesense.Analytics.html#create_analytics_event/2"},{"type":"function","title":"OpenApiTypesense.Analytics.create_analytics_rule/2","doc":"Creates an analytics rule\n\nWhen an analytics rule is created, we give it a name and describe the type, the source collections and the destination collection.","ref":"OpenApiTypesense.Analytics.html#create_analytics_rule/2"},{"type":"function","title":"OpenApiTypesense.Analytics.delete_analytics_rule/2","doc":"Delete an analytics rule\n\nPermanently deletes an analytics rule, given it's name","ref":"OpenApiTypesense.Analytics.html#delete_analytics_rule/2"},{"type":"function","title":"OpenApiTypesense.Analytics.retrieve_analytics_rule/2","doc":"Retrieves an analytics rule\n\nRetrieve the details of an analytics rule, given it's name","ref":"OpenApiTypesense.Analytics.html#retrieve_analytics_rule/2"},{"type":"function","title":"OpenApiTypesense.Analytics.retrieve_analytics_rules/1","doc":"Retrieves all analytics rules\n\nRetrieve the details of all analytics rules","ref":"OpenApiTypesense.Analytics.html#retrieve_analytics_rules/1"},{"type":"function","title":"OpenApiTypesense.Analytics.upsert_analytics_rule/3","doc":"Upserts an analytics rule\n\nUpserts an analytics rule with the given name.","ref":"OpenApiTypesense.Analytics.html#upsert_analytics_rule/3"},{"type":"module","title":"OpenApiTypesense.Collections","doc":"Provides API endpoints related to collections","ref":"OpenApiTypesense.Collections.html"},{"type":"function","title":"OpenApiTypesense.Collections.create_collection/2","doc":"Create a new collection\n\nWhen a collection is created, we give it a name and describe the fields that will be indexed from the documents added to the collection.","ref":"OpenApiTypesense.Collections.html#create_collection/2"},{"type":"function","title":"Options - OpenApiTypesense.Collections.create_collection/2","doc":"* `src_name`: Clone an existing collection's schema (documents are not copied), overrides and synonyms. The actual documents in the collection are not copied, so this is primarily useful for creating new collections from an existing reference template.","ref":"OpenApiTypesense.Collections.html#create_collection/2-options"},{"type":"function","title":"Example - OpenApiTypesense.Collections.create_collection/2","doc":"iex> schema = %{\n    ...>   \"name\" => \"houses\",\n    ...>   \"fields\" => [\n    ...>     %{\"name\" => \"house_type\", \"type\" => \"string\"},\n    ...>     %{\"name\" => \"houses_id\", \"type\" => \"int32\"},\n    ...>     %{\"name\" => \"description\", \"type\" => \"string\"},\n    ...>   ],\n    ...>   \"default_sorting_field\" => \"houses_id\",\n    ...> }\n    iex> OpenApiTypesense.Collections.create_collection(schema)","ref":"OpenApiTypesense.Collections.html#create_collection/2-example"},{"type":"function","title":"OpenApiTypesense.Collections.delete_alias/2","doc":"Delete an alias","ref":"OpenApiTypesense.Collections.html#delete_alias/2"},{"type":"function","title":"OpenApiTypesense.Collections.delete_collection/2","doc":"Delete a collection\n\nPermanently drops a collection. This action cannot be undone. For large collections, this might have an impact on read latencies.","ref":"OpenApiTypesense.Collections.html#delete_collection/2"},{"type":"function","title":"OpenApiTypesense.Collections.get_alias/2","doc":"Retrieve an alias\n\nFind out which collection an alias points to by fetching it","ref":"OpenApiTypesense.Collections.html#get_alias/2"},{"type":"function","title":"OpenApiTypesense.Collections.get_aliases/1","doc":"List all aliases\n\nList all aliases and the corresponding collections that they map to.","ref":"OpenApiTypesense.Collections.html#get_aliases/1"},{"type":"function","title":"OpenApiTypesense.Collections.get_collection/2","doc":"Retrieve a single collection\n\nRetrieve the details of a collection, given its name.","ref":"OpenApiTypesense.Collections.html#get_collection/2"},{"type":"function","title":"OpenApiTypesense.Collections.get_collections/1","doc":"List all collections\n\nReturns a summary of all your collections. The collections are returned sorted by creation date, with the most recent collections appearing first.","ref":"OpenApiTypesense.Collections.html#get_collections/1"},{"type":"function","title":"Options - OpenApiTypesense.Collections.get_collections/1","doc":"* `limit`: Limit results in paginating on collection listing.\n  * `offset`: Skip a certain number of results and start after that.\n  * `exclude_fields`: Exclude the field definitions from being returned in the response.","ref":"OpenApiTypesense.Collections.html#get_collections/1-options"},{"type":"function","title":"OpenApiTypesense.Collections.update_collection/3","doc":"Update a collection\n\nUpdate a collection's schema to modify the fields and their types.","ref":"OpenApiTypesense.Collections.html#update_collection/3"},{"type":"function","title":"OpenApiTypesense.Collections.upsert_alias/3","doc":"Create or update a collection alias\n\nCreate or update a collection alias. An alias is a virtual collection name that points to a real collection. If you're familiar with symbolic links on Linux, it's very similar to that. Aliases are useful when you want to reindex your data in the background on a new collection and switch your application to it without any changes to your code.","ref":"OpenApiTypesense.Collections.html#upsert_alias/3"},{"type":"module","title":"OpenApiTypesense.Conversations","doc":"Provides API endpoints related to conversations","ref":"OpenApiTypesense.Conversations.html"},{"type":"function","title":"OpenApiTypesense.Conversations.create_conversation_model/2","doc":"post `/conversations/models`\n\nCreate a Conversation Model","ref":"OpenApiTypesense.Conversations.html#create_conversation_model/2"},{"type":"function","title":"OpenApiTypesense.Conversations.delete_conversation_model/2","doc":"Delete a conversation model\n\nDelete a conversation model","ref":"OpenApiTypesense.Conversations.html#delete_conversation_model/2"},{"type":"function","title":"OpenApiTypesense.Conversations.retrieve_all_conversation_models/1","doc":"List all conversation models\n\nRetrieve all conversation models","ref":"OpenApiTypesense.Conversations.html#retrieve_all_conversation_models/1"},{"type":"function","title":"OpenApiTypesense.Conversations.retrieve_conversation_model/2","doc":"Retrieve a conversation model\n\nRetrieve a conversation model","ref":"OpenApiTypesense.Conversations.html#retrieve_conversation_model/2"},{"type":"function","title":"OpenApiTypesense.Conversations.update_conversation_model/3","doc":"Update a conversation model\n\nUpdate a conversation model","ref":"OpenApiTypesense.Conversations.html#update_conversation_model/3"},{"type":"module","title":"OpenApiTypesense.Curation","doc":"Provides API endpoints related to curation","ref":"OpenApiTypesense.Curation.html"},{"type":"function","title":"OpenApiTypesense.Curation.delete_search_override/3","doc":"Delete an override associated with a collection","ref":"OpenApiTypesense.Curation.html#delete_search_override/3"},{"type":"function","title":"OpenApiTypesense.Curation.get_search_overrides/2","doc":"List all collection overrides","ref":"OpenApiTypesense.Curation.html#get_search_overrides/2"},{"type":"function","title":"Options - OpenApiTypesense.Curation.get_search_overrides/2","doc":"* `limit`: Limit results in paginating on collection listing.\n  * `offset`: Skip a certain number of results and start after that.","ref":"OpenApiTypesense.Curation.html#get_search_overrides/2-options"},{"type":"function","title":"OpenApiTypesense.Curation.upsert_search_override/4","doc":"Create or update an override to promote certain documents over others\n\nCreate or update an override to promote certain documents over others. Using overrides, you can include or exclude specific documents for a given query.","ref":"OpenApiTypesense.Curation.html#upsert_search_override/4"},{"type":"module","title":"OpenApiTypesense.Debug","doc":"Provides API endpoint related to debug","ref":"OpenApiTypesense.Debug.html"},{"type":"function","title":"OpenApiTypesense.Debug.debug/1","doc":"Print debugging information\n\nPrint debugging information","ref":"OpenApiTypesense.Debug.html#debug/1"},{"type":"type","title":"OpenApiTypesense.Debug.debug_200_json_resp/0","doc":"","ref":"OpenApiTypesense.Debug.html#t:debug_200_json_resp/0"},{"type":"module","title":"OpenApiTypesense.Documents","doc":"Provides API endpoints related to documents","ref":"OpenApiTypesense.Documents.html"},{"type":"function","title":"OpenApiTypesense.Documents.delete_document/3","doc":"Delete a document\n\nDelete an individual document from a collection by using its ID.","ref":"OpenApiTypesense.Documents.html#delete_document/3"},{"type":"function","title":"Options - OpenApiTypesense.Documents.delete_document/3","doc":"* `ignore_not_found`: Ignore the error and treat the deletion as success.","ref":"OpenApiTypesense.Documents.html#delete_document/3-options"},{"type":"function","title":"OpenApiTypesense.Documents.delete_documents/2","doc":"Delete a bunch of documents\n\nDelete a bunch of documents that match a specific filter condition. Use the `batch_size` parameter to control the number of documents that should deleted at a time. A larger value will speed up deletions, but will impact performance of other operations running on the server.","ref":"OpenApiTypesense.Documents.html#delete_documents/2"},{"type":"function","title":"Options - OpenApiTypesense.Documents.delete_documents/2","doc":"* `batch_size`: Batch size parameter controls the number of documents that should be deleted at a time. A larger value will speed up deletions, but will impact performance of other operations running on the server.\n  * `filter_by`: Filter results by a particular value(s) or logical expressions. multiple conditions with &&.\n  * `ignore_not_found`: To ignore an error and treat the deletion as success.\n  * `truncate`: When true, removes all documents from the collection while preserving the collection and its schema.","ref":"OpenApiTypesense.Documents.html#delete_documents/2-options"},{"type":"type","title":"OpenApiTypesense.Documents.delete_documents_200_json_resp/0","doc":"","ref":"OpenApiTypesense.Documents.html#t:delete_documents_200_json_resp/0"},{"type":"function","title":"OpenApiTypesense.Documents.delete_search_override/3","doc":"Delete an override associated with a collection","ref":"OpenApiTypesense.Documents.html#delete_search_override/3"},{"type":"function","title":"OpenApiTypesense.Documents.export_documents/2","doc":"Export all documents in a collection\n\nExport all documents in a collection in JSON lines format.","ref":"OpenApiTypesense.Documents.html#export_documents/2"},{"type":"function","title":"Options - OpenApiTypesense.Documents.export_documents/2","doc":"* `filter_by`: Filter conditions for refining your search results. Separate multiple conditions with &&.\n  * `include_fields`: List of fields from the document to include in the search result\n  * `exclude_fields`: List of fields from the document to exclude in the search result","ref":"OpenApiTypesense.Documents.html#export_documents/2-options"},{"type":"function","title":"OpenApiTypesense.Documents.get_document/3","doc":"Retrieve a document\n\nFetch an individual document from a collection by using its ID.","ref":"OpenApiTypesense.Documents.html#get_document/3"},{"type":"function","title":"Options - OpenApiTypesense.Documents.get_document/3","doc":"* `include_fields`: List of fields that should be present in the returned document.\n  * `exclude_fields`: List of fields that should not be present in the returned document.","ref":"OpenApiTypesense.Documents.html#get_document/3-options"},{"type":"function","title":"OpenApiTypesense.Documents.get_search_override/3","doc":"Retrieve a single search override\n\nRetrieve the details of a search override, given its id.","ref":"OpenApiTypesense.Documents.html#get_search_override/3"},{"type":"function","title":"OpenApiTypesense.Documents.get_search_overrides/2","doc":"List all collection overrides","ref":"OpenApiTypesense.Documents.html#get_search_overrides/2"},{"type":"function","title":"Options - OpenApiTypesense.Documents.get_search_overrides/2","doc":"* `limit`: Limit results in paginating on collection listing.\n  * `offset`: Skip a certain number of results and start after that.","ref":"OpenApiTypesense.Documents.html#get_search_overrides/2-options"},{"type":"function","title":"OpenApiTypesense.Documents.import_documents/3","doc":"Import documents into a collection\n\nThe documents to be imported must be formatted in a newline delimited JSON structure. You can feed the output file from a Typesense export operation directly as import.","ref":"OpenApiTypesense.Documents.html#import_documents/3"},{"type":"function","title":"Options - OpenApiTypesense.Documents.import_documents/3","doc":"* `batch_size`: Batch size parameter controls the number of documents that should be imported at a time. A larger value will speed up imports, but will impact performance of other operations running on the server.\n  * `return_id`: Returning the id of the imported documents. If you want the import response to return the ingested document's id in the response, you can use the return_id parameter.\n  * `remote_embedding_batch_size`: Max size of each batch that will be sent to remote APIs while importing multiple documents at once. Using lower amount will lower timeout risk, but increase number of requests made. Default is 200.\n  * `remote_embedding_timeout_ms`: How long to wait until an API call to a remote embedding service is considered a timeout during indexing. Default is 60_000 ms\n  * `remote_embedding_num_tries`: The number of times to retry an API call to a remote embedding service on failure during indexing. Default is 2.\n  * `return_doc`: Returns the entire document back in response.\n  * `action`: Additional action to perform\n  * `dirty_values`: Dealing with Dirty Data","ref":"OpenApiTypesense.Documents.html#import_documents/3-options"},{"type":"function","title":"OpenApiTypesense.Documents.index_document/3","doc":"Index a document\n\nA document to be indexed in a given collection must conform to the schema of the collection.","ref":"OpenApiTypesense.Documents.html#index_document/3"},{"type":"function","title":"Options - OpenApiTypesense.Documents.index_document/3","doc":"* `action`: Additional action to perform\n  * `dirty_values`: Dealing with Dirty Data","ref":"OpenApiTypesense.Documents.html#index_document/3-options"},{"type":"function","title":"OpenApiTypesense.Documents.multi_search/2","doc":"send multiple search requests in a single HTTP request\n\nThis is especially useful to avoid round-trip network latencies incurred otherwise if each of these requests are sent in separate HTTP requests. You can also use this feature to do a federated search across multiple collections in a single HTTP request.","ref":"OpenApiTypesense.Documents.html#multi_search/2"},{"type":"function","title":"Options - OpenApiTypesense.Documents.multi_search/2","doc":"* `limit_multi_searches`: Max number of search requests that can be sent in a multi-search request. Default 50\n  * `x-typesense-api-key`: You can embed a separate search API key for each search within a multi_search request. This is useful when you want to apply different embedded filters for each collection in individual scoped API keys.","ref":"OpenApiTypesense.Documents.html#multi_search/2-options"},{"type":"function","title":"OpenApiTypesense.Documents.search_collection/2","doc":"Search for documents in a collection\n\nSearch for documents in a collection that match the search criteria.","ref":"OpenApiTypesense.Documents.html#search_collection/2"},{"type":"function","title":"Options - OpenApiTypesense.Documents.search_collection/2","doc":"* `searchParameters` can be found here:\n  https://typesense.org/docs/latest/api/search.html#search-parameters\n\nEither one of:\n- `search_collection(collectionName, params)`\n- `search_collection(%{api_key: xyz, host: ...}, collectionName, params)`\n- `search_collection(Connection.new(), collectionName, params)`","ref":"OpenApiTypesense.Documents.html#search_collection/2-options"},{"type":"function","title":"Example - OpenApiTypesense.Documents.search_collection/2","doc":"iex> schema = %{\n    ...>   \"name\" => \"houses\",\n    ...>   \"fields\" => [\n    ...>     %{\"name\" => \"house_type\", \"type\" => \"string\"},\n    ...>     %{\"name\" => \"houses_id\", \"type\" => \"int32\"},\n    ...>     %{\"name\" => \"description\", \"type\" => \"string\"},\n    ...>   ],\n    ...>   \"default_sorting_field\" => \"houses_id\",\n    ...> }\n    iex> OpenApiTypesense.Collections.create_collection(schema)\n    iex> params = [q: \"duplex\", query_by: \"house_type\"]\n    ...> OpenApiTypesense.Documents.search_collection(\"houses\", params)","ref":"OpenApiTypesense.Documents.html#search_collection/2-example"},{"type":"function","title":"OpenApiTypesense.Documents.update_document/4","doc":"Update a document\n\nUpdate an individual document from a collection by using its ID. The update can be partial.","ref":"OpenApiTypesense.Documents.html#update_document/4"},{"type":"function","title":"Options - OpenApiTypesense.Documents.update_document/4","doc":"* `dirty_values`: Dealing with Dirty Data","ref":"OpenApiTypesense.Documents.html#update_document/4-options"},{"type":"function","title":"OpenApiTypesense.Documents.update_documents/3","doc":"Update documents with conditional query\n\nThe filter_by query parameter is used to filter to specify a condition against which the documents are matched. The request body contains the fields that should be updated for any documents that match the filter condition. This endpoint is only available if the Typesense server is version `0.25.0.rc12` or later.","ref":"OpenApiTypesense.Documents.html#update_documents/3"},{"type":"function","title":"Options - OpenApiTypesense.Documents.update_documents/3","doc":"* `filter_by`: Filter results by a particular value(s) or logical expressions. multiple conditions with &&.\n  * `action`: Additional action to perform","ref":"OpenApiTypesense.Documents.html#update_documents/3-options"},{"type":"type","title":"OpenApiTypesense.Documents.update_documents_200_json_resp/0","doc":"","ref":"OpenApiTypesense.Documents.html#t:update_documents_200_json_resp/0"},{"type":"function","title":"OpenApiTypesense.Documents.upsert_search_override/4","doc":"Create or update an override to promote certain documents over others\n\nCreate or update an override to promote certain documents over others. Using overrides, you can include or exclude specific documents for a given query.","ref":"OpenApiTypesense.Documents.html#upsert_search_override/4"},{"type":"module","title":"OpenApiTypesense.Health","doc":"Provides API endpoint related to health","ref":"OpenApiTypesense.Health.html"},{"type":"function","title":"OpenApiTypesense.Health.health/1","doc":"Checks if Typesense server is ready to accept requests.\n\nChecks if Typesense server is ready to accept requests.","ref":"OpenApiTypesense.Health.html#health/1"},{"type":"module","title":"OpenApiTypesense.Keys","doc":"Provides API endpoints related to keys","ref":"OpenApiTypesense.Keys.html"},{"type":"function","title":"OpenApiTypesense.Keys.create_key/2","doc":"Create an API Key\n\nCreate an API Key with fine-grain access control. You can restrict access on both a per-collection and per-action level. The generated key is returned only during creation. You want to store this key carefully in a secure place.","ref":"OpenApiTypesense.Keys.html#create_key/2"},{"type":"function","title":"OpenApiTypesense.Keys.delete_key/2","doc":"Delete an API key given its ID.","ref":"OpenApiTypesense.Keys.html#delete_key/2"},{"type":"function","title":"OpenApiTypesense.Keys.get_key/2","doc":"Retrieve (metadata about) a key\n\nRetrieve (metadata about) a key. Only the key prefix is returned when you retrieve a key. Due to security reasons, only the create endpoint returns the full API key.","ref":"OpenApiTypesense.Keys.html#get_key/2"},{"type":"function","title":"OpenApiTypesense.Keys.get_keys/1","doc":"Retrieve (metadata about) all keys.","ref":"OpenApiTypesense.Keys.html#get_keys/1"},{"type":"module","title":"OpenApiTypesense.Operations","doc":"Provides API endpoints related to operations","ref":"OpenApiTypesense.Operations.html"},{"type":"function","title":"OpenApiTypesense.Operations.clear_cache/1","doc":"Clears the cache\n\nResponses of search requests that are sent with use_cache parameter are cached in a LRU cache. Clears cache completely.","ref":"OpenApiTypesense.Operations.html#clear_cache/1"},{"type":"function","title":"OpenApiTypesense.Operations.compact/1","doc":"Compaction of the underlying RocksDB database\n\nTypesense uses RocksDB to store your documents on the disk. If you do frequent writes or updates, you could benefit from running a compaction of the underlying RocksDB database. This could reduce the size of the database and decrease read latency. While the database will not block during this operation, we recommend running it during off-peak hours.","ref":"OpenApiTypesense.Operations.html#compact/1"},{"type":"function","title":"OpenApiTypesense.Operations.config/2","doc":"Enable logging of requests that take over a defined threshold of time.\n\nSlow requests are logged to the primary log file, with the prefix SLOW REQUEST. Default is -1 which disables slow request logging.","ref":"OpenApiTypesense.Operations.html#config/2"},{"type":"function","title":"OpenApiTypesense.Operations.get_schema_changes/1","doc":"Get the status of in-progress schema change operations\n\nReturns the status of any ongoing schema change operations. If no schema changes are in progress, returns an empty response.","ref":"OpenApiTypesense.Operations.html#get_schema_changes/1"},{"type":"function","title":"OpenApiTypesense.Operations.retrieve_api_stats/1","doc":"Get stats about API endpoints.\n\nRetrieve the stats about API endpoints.","ref":"OpenApiTypesense.Operations.html#retrieve_api_stats/1"},{"type":"function","title":"OpenApiTypesense.Operations.retrieve_metrics/1","doc":"Get current RAM, CPU, Disk & Network usage metrics.\n\nRetrieve the metrics.","ref":"OpenApiTypesense.Operations.html#retrieve_metrics/1"},{"type":"function","title":"OpenApiTypesense.Operations.take_snapshot/1","doc":"Creates a point-in-time snapshot of a Typesense node's state and data in the specified directory.\n\nCreates a point-in-time snapshot of a Typesense node's state and data in the specified directory. You can then backup the snapshot directory that gets created and later restore it as a data directory, as needed.","ref":"OpenApiTypesense.Operations.html#take_snapshot/1"},{"type":"function","title":"Options - OpenApiTypesense.Operations.take_snapshot/1","doc":"* `snapshot_path`: The directory on the server where the snapshot should be saved.","ref":"OpenApiTypesense.Operations.html#take_snapshot/1-options"},{"type":"function","title":"OpenApiTypesense.Operations.vote/1","doc":"Triggers a follower node to initiate the raft voting process, which triggers leader re-election.\n\nTriggers a follower node to initiate the raft voting process, which triggers leader re-election. The follower node that you run this operation against will become the new leader, once this command succeeds.","ref":"OpenApiTypesense.Operations.html#vote/1"},{"type":"module","title":"OpenApiTypesense.Override","doc":"Provides API endpoint related to override","ref":"OpenApiTypesense.Override.html"},{"type":"function","title":"OpenApiTypesense.Override.get_search_override/3","doc":"Retrieve a single search override\n\nRetrieve the details of a search override, given its id.","ref":"OpenApiTypesense.Override.html#get_search_override/3"},{"type":"module","title":"OpenApiTypesense.Presets","doc":"Provides API endpoints related to presets","ref":"OpenApiTypesense.Presets.html"},{"type":"function","title":"OpenApiTypesense.Presets.delete_preset/2","doc":"Delete a preset.\n\nPermanently deletes a preset, given it's name.","ref":"OpenApiTypesense.Presets.html#delete_preset/2"},{"type":"function","title":"OpenApiTypesense.Presets.retrieve_all_presets/1","doc":"Retrieves all presets.\n\nRetrieve the details of all presets","ref":"OpenApiTypesense.Presets.html#retrieve_all_presets/1"},{"type":"function","title":"OpenApiTypesense.Presets.retrieve_preset/2","doc":"Retrieves a preset.\n\nRetrieve the details of a preset, given it's name.","ref":"OpenApiTypesense.Presets.html#retrieve_preset/2"},{"type":"function","title":"OpenApiTypesense.Presets.upsert_preset/3","doc":"Upserts a preset.\n\nCreate or update an existing preset.","ref":"OpenApiTypesense.Presets.html#upsert_preset/3"},{"type":"module","title":"OpenApiTypesense.Stemming","doc":"Provides API endpoints related to stemming","ref":"OpenApiTypesense.Stemming.html"},{"type":"function","title":"OpenApiTypesense.Stemming.get_stemming_dictionary/2","doc":"Retrieve a stemming dictionary\n\nFetch details of a specific stemming dictionary.","ref":"OpenApiTypesense.Stemming.html#get_stemming_dictionary/2"},{"type":"function","title":"OpenApiTypesense.Stemming.import_stemming_dictionary/2","doc":"Import a stemming dictionary\n\nUpload a JSONL file containing word mappings to create or update a stemming dictionary.","ref":"OpenApiTypesense.Stemming.html#import_stemming_dictionary/2"},{"type":"function","title":"Options - OpenApiTypesense.Stemming.import_stemming_dictionary/2","doc":"* `id`: The ID to assign to the dictionary","ref":"OpenApiTypesense.Stemming.html#import_stemming_dictionary/2-options"},{"type":"function","title":"Example - OpenApiTypesense.Stemming.import_stemming_dictionary/2","doc":"iex> body = [\n    ...>   %{\"word\" => \"people\", \"root\" => \"person\"}\n    ...>   %{\"word\" => \"children\", \"root\" => \"child\"}\n    ...>   %{\"word\" => \"geese\", \"root\" => \"goose\"}\n    ...> ]\n    iex> OpenApiTypesense.Stemming.import_stemming_dictionary(body, id: \"irregular-plurals\")","ref":"OpenApiTypesense.Stemming.html#import_stemming_dictionary/2-example"},{"type":"function","title":"OpenApiTypesense.Stemming.list_stemming_dictionaries/1","doc":"List all stemming dictionaries\n\nRetrieve a list of all available stemming dictionaries.","ref":"OpenApiTypesense.Stemming.html#list_stemming_dictionaries/1"},{"type":"type","title":"OpenApiTypesense.Stemming.list_stemming_dictionaries_200_json_resp/0","doc":"","ref":"OpenApiTypesense.Stemming.html#t:list_stemming_dictionaries_200_json_resp/0"},{"type":"module","title":"OpenApiTypesense.Stopwords","doc":"Provides API endpoints related to stopwords","ref":"OpenApiTypesense.Stopwords.html"},{"type":"function","title":"OpenApiTypesense.Stopwords.delete_stopwords_set/2","doc":"Delete a stopwords set.\n\nPermanently deletes a stopwords set, given it's name.","ref":"OpenApiTypesense.Stopwords.html#delete_stopwords_set/2"},{"type":"type","title":"OpenApiTypesense.Stopwords.delete_stopwords_set_200_json_resp/0","doc":"","ref":"OpenApiTypesense.Stopwords.html#t:delete_stopwords_set_200_json_resp/0"},{"type":"function","title":"OpenApiTypesense.Stopwords.retrieve_stopwords_set/2","doc":"Retrieves a stopwords set.\n\nRetrieve the details of a stopwords set, given it's name.","ref":"OpenApiTypesense.Stopwords.html#retrieve_stopwords_set/2"},{"type":"function","title":"OpenApiTypesense.Stopwords.retrieve_stopwords_sets/1","doc":"Retrieves all stopwords sets.\n\nRetrieve the details of all stopwords sets","ref":"OpenApiTypesense.Stopwords.html#retrieve_stopwords_sets/1"},{"type":"function","title":"OpenApiTypesense.Stopwords.upsert_stopwords_set/3","doc":"Upserts a stopwords set.\n\nWhen an analytics rule is created, we give it a name and describe the type, the source collections and the destination collection.","ref":"OpenApiTypesense.Stopwords.html#upsert_stopwords_set/3"},{"type":"module","title":"OpenApiTypesense.Synonyms","doc":"Provides API endpoints related to synonyms","ref":"OpenApiTypesense.Synonyms.html"},{"type":"function","title":"OpenApiTypesense.Synonyms.delete_search_synonym/3","doc":"Delete a synonym associated with a collection","ref":"OpenApiTypesense.Synonyms.html#delete_search_synonym/3"},{"type":"function","title":"OpenApiTypesense.Synonyms.get_search_synonym/3","doc":"Retrieve a single search synonym\n\nRetrieve the details of a search synonym, given its id.","ref":"OpenApiTypesense.Synonyms.html#get_search_synonym/3"},{"type":"function","title":"OpenApiTypesense.Synonyms.get_search_synonyms/2","doc":"List all collection synonyms","ref":"OpenApiTypesense.Synonyms.html#get_search_synonyms/2"},{"type":"function","title":"Options - OpenApiTypesense.Synonyms.get_search_synonyms/2","doc":"* `limit`: Limit results in paginating on collection listing.\n  * `offset`: Skip a certain number of results and start after that.","ref":"OpenApiTypesense.Synonyms.html#get_search_synonyms/2-options"},{"type":"function","title":"OpenApiTypesense.Synonyms.upsert_search_synonym/4","doc":"Create or update a synonym\n\nCreate or update a synonym  to define search terms that should be considered equivalent.","ref":"OpenApiTypesense.Synonyms.html#upsert_search_synonym/4"},{"type":"module","title":"OpenApiTypesense.APIStatsResponse","doc":"Provides struct and type for a APIStatsResponse","ref":"OpenApiTypesense.APIStatsResponse.html"},{"type":"type","title":"OpenApiTypesense.APIStatsResponse.t/0","doc":"","ref":"OpenApiTypesense.APIStatsResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsEventCreateResponse","doc":"Provides struct and type for a AnalyticsEventCreateResponse","ref":"OpenApiTypesense.AnalyticsEventCreateResponse.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsEventCreateResponse.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsEventCreateResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsEventCreateSchema","doc":"Provides struct and type for a AnalyticsEventCreateSchema","ref":"OpenApiTypesense.AnalyticsEventCreateSchema.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsEventCreateSchema.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsEventCreateSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsRuleDeleteResponse","doc":"Provides struct and type for a AnalyticsRuleDeleteResponse","ref":"OpenApiTypesense.AnalyticsRuleDeleteResponse.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsRuleDeleteResponse.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsRuleDeleteResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsRuleParameters","doc":"Provides struct and type for a AnalyticsRuleParameters","ref":"OpenApiTypesense.AnalyticsRuleParameters.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsRuleParameters.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsRuleParameters.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsRuleParametersDestination","doc":"Provides struct and type for a AnalyticsRuleParametersDestination","ref":"OpenApiTypesense.AnalyticsRuleParametersDestination.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsRuleParametersDestination.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsRuleParametersDestination.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsRuleParametersSource","doc":"Provides struct and type for a AnalyticsRuleParametersSource","ref":"OpenApiTypesense.AnalyticsRuleParametersSource.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsRuleParametersSource.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsRuleParametersSource.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsRuleParametersSourceEvents","doc":"Provides struct and type for a AnalyticsRuleParametersSourceEvents","ref":"OpenApiTypesense.AnalyticsRuleParametersSourceEvents.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsRuleParametersSourceEvents.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsRuleParametersSourceEvents.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsRuleSchema","doc":"Provides struct and type for a AnalyticsRuleSchema","ref":"OpenApiTypesense.AnalyticsRuleSchema.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsRuleSchema.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsRuleSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsRuleUpsertSchema","doc":"Provides struct and type for a AnalyticsRuleUpsertSchema","ref":"OpenApiTypesense.AnalyticsRuleUpsertSchema.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsRuleUpsertSchema.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsRuleUpsertSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.AnalyticsRulesRetrieveSchema","doc":"Provides struct and type for a AnalyticsRulesRetrieveSchema","ref":"OpenApiTypesense.AnalyticsRulesRetrieveSchema.html"},{"type":"type","title":"OpenApiTypesense.AnalyticsRulesRetrieveSchema.t/0","doc":"","ref":"OpenApiTypesense.AnalyticsRulesRetrieveSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.ApiKey","doc":"Provides struct and type for a ApiKey","ref":"OpenApiTypesense.ApiKey.html"},{"type":"type","title":"OpenApiTypesense.ApiKey.t/0","doc":"","ref":"OpenApiTypesense.ApiKey.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.ApiKeyDeleteResponse","doc":"Provides struct and type for a ApiKeyDeleteResponse","ref":"OpenApiTypesense.ApiKeyDeleteResponse.html"},{"type":"type","title":"OpenApiTypesense.ApiKeyDeleteResponse.t/0","doc":"","ref":"OpenApiTypesense.ApiKeyDeleteResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.ApiKeySchema","doc":"Provides struct and type for a ApiKeySchema","ref":"OpenApiTypesense.ApiKeySchema.html"},{"type":"type","title":"OpenApiTypesense.ApiKeySchema.t/0","doc":"","ref":"OpenApiTypesense.ApiKeySchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.ApiKeysResponse","doc":"Provides struct and type for a ApiKeysResponse","ref":"OpenApiTypesense.ApiKeysResponse.html"},{"type":"type","title":"OpenApiTypesense.ApiKeysResponse.t/0","doc":"","ref":"OpenApiTypesense.ApiKeysResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.ApiResponse","doc":"Provides struct and type for a ApiResponse","ref":"OpenApiTypesense.ApiResponse.html"},{"type":"type","title":"OpenApiTypesense.ApiResponse.t/0","doc":"","ref":"OpenApiTypesense.ApiResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.CollectionAlias","doc":"Provides struct and type for a CollectionAlias","ref":"OpenApiTypesense.CollectionAlias.html"},{"type":"type","title":"OpenApiTypesense.CollectionAlias.t/0","doc":"","ref":"OpenApiTypesense.CollectionAlias.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.CollectionAliasSchema","doc":"Provides struct and type for a CollectionAliasSchema","ref":"OpenApiTypesense.CollectionAliasSchema.html"},{"type":"type","title":"OpenApiTypesense.CollectionAliasSchema.t/0","doc":"","ref":"OpenApiTypesense.CollectionAliasSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.CollectionAliasesResponse","doc":"Provides struct and type for a CollectionAliasesResponse","ref":"OpenApiTypesense.CollectionAliasesResponse.html"},{"type":"type","title":"OpenApiTypesense.CollectionAliasesResponse.t/0","doc":"","ref":"OpenApiTypesense.CollectionAliasesResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.CollectionResponse","doc":"Provides struct and type for a CollectionResponse","ref":"OpenApiTypesense.CollectionResponse.html"},{"type":"type","title":"OpenApiTypesense.CollectionResponse.t/0","doc":"","ref":"OpenApiTypesense.CollectionResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.CollectionSchema","doc":"Provides struct and type for a CollectionSchema","ref":"OpenApiTypesense.CollectionSchema.html"},{"type":"type","title":"OpenApiTypesense.CollectionSchema.t/0","doc":"","ref":"OpenApiTypesense.CollectionSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.CollectionUpdateSchema","doc":"Provides struct and type for a CollectionUpdateSchema","ref":"OpenApiTypesense.CollectionUpdateSchema.html"},{"type":"type","title":"OpenApiTypesense.CollectionUpdateSchema.t/0","doc":"","ref":"OpenApiTypesense.CollectionUpdateSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.ConfigSchema","doc":"Provides struct and type for a ConfigSchema","ref":"OpenApiTypesense.ConfigSchema.html"},{"type":"type","title":"OpenApiTypesense.ConfigSchema.t/0","doc":"","ref":"OpenApiTypesense.ConfigSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.ConversationModelCreateSchema","doc":"Provides struct and type for a ConversationModelCreateSchema","ref":"OpenApiTypesense.ConversationModelCreateSchema.html"},{"type":"type","title":"OpenApiTypesense.ConversationModelCreateSchema.t/0","doc":"","ref":"OpenApiTypesense.ConversationModelCreateSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.ConversationModelSchema","doc":"Provides struct and type for a ConversationModelSchema","ref":"OpenApiTypesense.ConversationModelSchema.html"},{"type":"type","title":"OpenApiTypesense.ConversationModelSchema.t/0","doc":"","ref":"OpenApiTypesense.ConversationModelSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.ConversationModelUpdateSchema","doc":"Provides struct and type for a ConversationModelUpdateSchema","ref":"OpenApiTypesense.ConversationModelUpdateSchema.html"},{"type":"type","title":"OpenApiTypesense.ConversationModelUpdateSchema.t/0","doc":"","ref":"OpenApiTypesense.ConversationModelUpdateSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.FacetCounts","doc":"Provides struct and type for a FacetCounts","ref":"OpenApiTypesense.FacetCounts.html"},{"type":"type","title":"OpenApiTypesense.FacetCounts.t/0","doc":"","ref":"OpenApiTypesense.FacetCounts.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.FacetCountsCounts","doc":"Provides struct and type for a FacetCountsCounts","ref":"OpenApiTypesense.FacetCountsCounts.html"},{"type":"type","title":"OpenApiTypesense.FacetCountsCounts.t/0","doc":"","ref":"OpenApiTypesense.FacetCountsCounts.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.FacetCountsStats","doc":"Provides struct and type for a FacetCountsStats","ref":"OpenApiTypesense.FacetCountsStats.html"},{"type":"type","title":"OpenApiTypesense.FacetCountsStats.t/0","doc":"","ref":"OpenApiTypesense.FacetCountsStats.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.Field","doc":"Provides struct and type for a Field","ref":"OpenApiTypesense.Field.html"},{"type":"type","title":"OpenApiTypesense.Field.t/0","doc":"","ref":"OpenApiTypesense.Field.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.FieldEmbed","doc":"Provides struct and type for a FieldEmbed","ref":"OpenApiTypesense.FieldEmbed.html"},{"type":"type","title":"OpenApiTypesense.FieldEmbed.t/0","doc":"","ref":"OpenApiTypesense.FieldEmbed.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.FieldEmbedModelConfig","doc":"Provides struct and type for a FieldEmbedModelConfig","ref":"OpenApiTypesense.FieldEmbedModelConfig.html"},{"type":"type","title":"OpenApiTypesense.FieldEmbedModelConfig.t/0","doc":"","ref":"OpenApiTypesense.FieldEmbedModelConfig.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.HealthStatus","doc":"Provides struct and type for a HealthStatus","ref":"OpenApiTypesense.HealthStatus.html"},{"type":"type","title":"OpenApiTypesense.HealthStatus.t/0","doc":"","ref":"OpenApiTypesense.HealthStatus.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.MultiSearchCollectionParameters","doc":"Provides struct and type for a MultiSearchCollectionParameters","ref":"OpenApiTypesense.MultiSearchCollectionParameters.html"},{"type":"type","title":"OpenApiTypesense.MultiSearchCollectionParameters.t/0","doc":"","ref":"OpenApiTypesense.MultiSearchCollectionParameters.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.MultiSearchResult","doc":"Provides struct and type for a MultiSearchResult","ref":"OpenApiTypesense.MultiSearchResult.html"},{"type":"type","title":"OpenApiTypesense.MultiSearchResult.t/0","doc":"","ref":"OpenApiTypesense.MultiSearchResult.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.MultiSearchResultItem","doc":"Provides struct and type for a MultiSearchResultItem","ref":"OpenApiTypesense.MultiSearchResultItem.html"},{"type":"type","title":"OpenApiTypesense.MultiSearchResultItem.t/0","doc":"","ref":"OpenApiTypesense.MultiSearchResultItem.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.MultiSearchSearchesParameter","doc":"Provides struct and type for a MultiSearchSearchesParameter","ref":"OpenApiTypesense.MultiSearchSearchesParameter.html"},{"type":"type","title":"OpenApiTypesense.MultiSearchSearchesParameter.t/0","doc":"","ref":"OpenApiTypesense.MultiSearchSearchesParameter.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.PresetDeleteSchema","doc":"Provides struct and type for a PresetDeleteSchema","ref":"OpenApiTypesense.PresetDeleteSchema.html"},{"type":"type","title":"OpenApiTypesense.PresetDeleteSchema.t/0","doc":"","ref":"OpenApiTypesense.PresetDeleteSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.PresetSchema","doc":"Provides struct and type for a PresetSchema","ref":"OpenApiTypesense.PresetSchema.html"},{"type":"type","title":"OpenApiTypesense.PresetSchema.t/0","doc":"","ref":"OpenApiTypesense.PresetSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.PresetUpsertSchema","doc":"Provides struct and type for a PresetUpsertSchema","ref":"OpenApiTypesense.PresetUpsertSchema.html"},{"type":"type","title":"OpenApiTypesense.PresetUpsertSchema.t/0","doc":"","ref":"OpenApiTypesense.PresetUpsertSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.PresetsRetrieveSchema","doc":"Provides struct and type for a PresetsRetrieveSchema","ref":"OpenApiTypesense.PresetsRetrieveSchema.html"},{"type":"type","title":"OpenApiTypesense.PresetsRetrieveSchema.t/0","doc":"","ref":"OpenApiTypesense.PresetsRetrieveSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SchemaChangeStatus","doc":"Provides struct and type for a SchemaChangeStatus","ref":"OpenApiTypesense.SchemaChangeStatus.html"},{"type":"type","title":"OpenApiTypesense.SchemaChangeStatus.t/0","doc":"","ref":"OpenApiTypesense.SchemaChangeStatus.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchGroupedHit","doc":"Provides struct and type for a SearchGroupedHit","ref":"OpenApiTypesense.SearchGroupedHit.html"},{"type":"type","title":"OpenApiTypesense.SearchGroupedHit.t/0","doc":"","ref":"OpenApiTypesense.SearchGroupedHit.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchHighlight","doc":"Provides struct and type for a SearchHighlight","ref":"OpenApiTypesense.SearchHighlight.html"},{"type":"type","title":"OpenApiTypesense.SearchHighlight.t/0","doc":"","ref":"OpenApiTypesense.SearchHighlight.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchOverride","doc":"Provides struct and type for a SearchOverride","ref":"OpenApiTypesense.SearchOverride.html"},{"type":"type","title":"OpenApiTypesense.SearchOverride.t/0","doc":"","ref":"OpenApiTypesense.SearchOverride.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchOverrideDeleteResponse","doc":"Provides struct and type for a SearchOverrideDeleteResponse","ref":"OpenApiTypesense.SearchOverrideDeleteResponse.html"},{"type":"type","title":"OpenApiTypesense.SearchOverrideDeleteResponse.t/0","doc":"","ref":"OpenApiTypesense.SearchOverrideDeleteResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchOverrideExclude","doc":"Provides struct and type for a SearchOverrideExclude","ref":"OpenApiTypesense.SearchOverrideExclude.html"},{"type":"type","title":"OpenApiTypesense.SearchOverrideExclude.t/0","doc":"","ref":"OpenApiTypesense.SearchOverrideExclude.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchOverrideInclude","doc":"Provides struct and type for a SearchOverrideInclude","ref":"OpenApiTypesense.SearchOverrideInclude.html"},{"type":"type","title":"OpenApiTypesense.SearchOverrideInclude.t/0","doc":"","ref":"OpenApiTypesense.SearchOverrideInclude.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchOverrideRule","doc":"Provides struct and type for a SearchOverrideRule","ref":"OpenApiTypesense.SearchOverrideRule.html"},{"type":"type","title":"OpenApiTypesense.SearchOverrideRule.t/0","doc":"","ref":"OpenApiTypesense.SearchOverrideRule.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchOverrideSchema","doc":"Provides struct and type for a SearchOverrideSchema","ref":"OpenApiTypesense.SearchOverrideSchema.html"},{"type":"type","title":"OpenApiTypesense.SearchOverrideSchema.t/0","doc":"","ref":"OpenApiTypesense.SearchOverrideSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchOverridesResponse","doc":"Provides struct and type for a SearchOverridesResponse","ref":"OpenApiTypesense.SearchOverridesResponse.html"},{"type":"type","title":"OpenApiTypesense.SearchOverridesResponse.t/0","doc":"","ref":"OpenApiTypesense.SearchOverridesResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchParameters","doc":"Provides struct and type for a SearchParameters","ref":"OpenApiTypesense.SearchParameters.html"},{"type":"type","title":"OpenApiTypesense.SearchParameters.t/0","doc":"","ref":"OpenApiTypesense.SearchParameters.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchResult","doc":"Provides struct and type for a SearchResult","ref":"OpenApiTypesense.SearchResult.html"},{"type":"type","title":"OpenApiTypesense.SearchResult.t/0","doc":"","ref":"OpenApiTypesense.SearchResult.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchResultConversation","doc":"Provides struct and type for a SearchResultConversation","ref":"OpenApiTypesense.SearchResultConversation.html"},{"type":"type","title":"OpenApiTypesense.SearchResultConversation.t/0","doc":"","ref":"OpenApiTypesense.SearchResultConversation.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchResultHit","doc":"Provides struct and type for a SearchResultHit","ref":"OpenApiTypesense.SearchResultHit.html"},{"type":"type","title":"OpenApiTypesense.SearchResultHit.t/0","doc":"","ref":"OpenApiTypesense.SearchResultHit.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchResultHitDocument","doc":"Provides struct and type for a SearchResultHitDocument","ref":"OpenApiTypesense.SearchResultHitDocument.html"},{"type":"type","title":"OpenApiTypesense.SearchResultHitDocument.t/0","doc":"","ref":"OpenApiTypesense.SearchResultHitDocument.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchResultHitGeoDistanceMeters","doc":"Provides struct and type for a SearchResultHitGeoDistanceMeters","ref":"OpenApiTypesense.SearchResultHitGeoDistanceMeters.html"},{"type":"type","title":"OpenApiTypesense.SearchResultHitGeoDistanceMeters.t/0","doc":"","ref":"OpenApiTypesense.SearchResultHitGeoDistanceMeters.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchResultHitTextMatchInfo","doc":"Provides struct and type for a SearchResultHitTextMatchInfo","ref":"OpenApiTypesense.SearchResultHitTextMatchInfo.html"},{"type":"type","title":"OpenApiTypesense.SearchResultHitTextMatchInfo.t/0","doc":"","ref":"OpenApiTypesense.SearchResultHitTextMatchInfo.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchResultRequestParams","doc":"Provides struct and type for a SearchResultRequestParams","ref":"OpenApiTypesense.SearchResultRequestParams.html"},{"type":"type","title":"OpenApiTypesense.SearchResultRequestParams.t/0","doc":"","ref":"OpenApiTypesense.SearchResultRequestParams.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchResultRequestParamsVoiceQuery","doc":"Provides struct and type for a SearchResultRequestParamsVoiceQuery","ref":"OpenApiTypesense.SearchResultRequestParamsVoiceQuery.html"},{"type":"type","title":"OpenApiTypesense.SearchResultRequestParamsVoiceQuery.t/0","doc":"","ref":"OpenApiTypesense.SearchResultRequestParamsVoiceQuery.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchSynonym","doc":"Provides struct and type for a SearchSynonym","ref":"OpenApiTypesense.SearchSynonym.html"},{"type":"type","title":"OpenApiTypesense.SearchSynonym.t/0","doc":"","ref":"OpenApiTypesense.SearchSynonym.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchSynonymDeleteResponse","doc":"Provides struct and type for a SearchSynonymDeleteResponse","ref":"OpenApiTypesense.SearchSynonymDeleteResponse.html"},{"type":"type","title":"OpenApiTypesense.SearchSynonymDeleteResponse.t/0","doc":"","ref":"OpenApiTypesense.SearchSynonymDeleteResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchSynonymSchema","doc":"Provides struct and type for a SearchSynonymSchema","ref":"OpenApiTypesense.SearchSynonymSchema.html"},{"type":"type","title":"OpenApiTypesense.SearchSynonymSchema.t/0","doc":"","ref":"OpenApiTypesense.SearchSynonymSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SearchSynonymsResponse","doc":"Provides struct and type for a SearchSynonymsResponse","ref":"OpenApiTypesense.SearchSynonymsResponse.html"},{"type":"type","title":"OpenApiTypesense.SearchSynonymsResponse.t/0","doc":"","ref":"OpenApiTypesense.SearchSynonymsResponse.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.StemmingDictionary","doc":"Provides struct and type for a StemmingDictionary","ref":"OpenApiTypesense.StemmingDictionary.html"},{"type":"type","title":"OpenApiTypesense.StemmingDictionary.t/0","doc":"","ref":"OpenApiTypesense.StemmingDictionary.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.StemmingDictionaryWords","doc":"Provides struct and type for a StemmingDictionaryWords","ref":"OpenApiTypesense.StemmingDictionaryWords.html"},{"type":"type","title":"OpenApiTypesense.StemmingDictionaryWords.t/0","doc":"","ref":"OpenApiTypesense.StemmingDictionaryWords.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.StopwordsSetRetrieveSchema","doc":"Provides struct and type for a StopwordsSetRetrieveSchema","ref":"OpenApiTypesense.StopwordsSetRetrieveSchema.html"},{"type":"type","title":"OpenApiTypesense.StopwordsSetRetrieveSchema.t/0","doc":"","ref":"OpenApiTypesense.StopwordsSetRetrieveSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.StopwordsSetSchema","doc":"Provides struct and type for a StopwordsSetSchema","ref":"OpenApiTypesense.StopwordsSetSchema.html"},{"type":"type","title":"OpenApiTypesense.StopwordsSetSchema.t/0","doc":"","ref":"OpenApiTypesense.StopwordsSetSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.StopwordsSetUpsertSchema","doc":"Provides struct and type for a StopwordsSetUpsertSchema","ref":"OpenApiTypesense.StopwordsSetUpsertSchema.html"},{"type":"type","title":"OpenApiTypesense.StopwordsSetUpsertSchema.t/0","doc":"","ref":"OpenApiTypesense.StopwordsSetUpsertSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.StopwordsSetsRetrieveAllSchema","doc":"Provides struct and type for a StopwordsSetsRetrieveAllSchema","ref":"OpenApiTypesense.StopwordsSetsRetrieveAllSchema.html"},{"type":"type","title":"OpenApiTypesense.StopwordsSetsRetrieveAllSchema.t/0","doc":"","ref":"OpenApiTypesense.StopwordsSetsRetrieveAllSchema.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.SuccessStatus","doc":"Provides struct and type for a SuccessStatus","ref":"OpenApiTypesense.SuccessStatus.html"},{"type":"type","title":"OpenApiTypesense.SuccessStatus.t/0","doc":"","ref":"OpenApiTypesense.SuccessStatus.html#t:t/0"},{"type":"module","title":"OpenApiTypesense.VoiceQueryModelCollectionConfig","doc":"Provides struct and type for a VoiceQueryModelCollectionConfig","ref":"OpenApiTypesense.VoiceQueryModelCollectionConfig.html"},{"type":"type","title":"OpenApiTypesense.VoiceQueryModelCollectionConfig.t/0","doc":"","ref":"OpenApiTypesense.VoiceQueryModelCollectionConfig.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"major.minor.patch (yyyy.mm.dd) - Changelog","doc":"","ref":"changelog.html#major-minor-patch-yyyy-mm-dd"},{"type":"extras","title":"1.0.3 (2025.06.16) - Changelog","doc":"","ref":"changelog.html#1-0-3-2025-06-16"},{"type":"extras","title":"Chore - Changelog","doc":"* Add few documents tests\n* Add custom encoder for JSON encoding all schemas.\n* Typespecs and client definitions to use snake casing for consistency.\n* Add custom renderer plugin for OpenAPI code gen.\n* Use fork version for open-api-generator, with added `default` field for generated schema.","ref":"changelog.html#chore"},{"type":"extras","title":"1.0.2 (2025.06.08) - Changelog","doc":"","ref":"changelog.html#1-0-2-2025-06-08"},{"type":"extras","title":"Fixed - Changelog","doc":"* Reduce unsafe atom keys conversion. [PR #30](https://github.com/jaeyson/open_api_typesense/pull/30)","ref":"changelog.html#fixed"},{"type":"extras","title":"1.0.1 (2025.06.06) - Changelog","doc":"","ref":"changelog.html#1-0-1-2025-06-06"},{"type":"extras","title":"Fixed - Changelog","doc":"* Typespecs for Documents and Stemmings. See [`ex_typesense` issue](https://github.com/jaeyson/ex_typesense/issues/80)","ref":"changelog.html#fixed-1"},{"type":"extras","title":"1.0.0 (2025.05.31) - Changelog","doc":"","ref":"changelog.html#1-0-0-2025-05-31"},{"type":"extras","title":"Changed - Changelog","doc":"* Passing `conn` as part of `opts` when calling a function, as this reduces code duplication. [Issue #26](https://github.com/jaeyson/open_api_typesense/issues/26) [PR #29](https://github.com/jaeyson/open_api_typesense/pull/29)","ref":"changelog.html#changed"},{"type":"extras","title":"Chore - Changelog","doc":"* Bumped dev dependencies","ref":"changelog.html#chore-1"},{"type":"extras","title":"0.7.1 (2025.04.06) - Changelog","doc":"","ref":"changelog.html#0-7-1-2025-04-06"},{"type":"extras","title":"Fixed - Changelog","doc":"* Parsing results from using multi search [unions](https://typesense.org/docs/28.0/api/federated-multi-search.html#union-search)","ref":"changelog.html#fixed-2"},{"type":"extras","title":"0.7.0 (2025.04.06) - Changelog","doc":"","ref":"changelog.html#0-7-0-2025-04-06"},{"type":"extras","title":"Changed (#28) - Changelog","doc":"* Update to include Typesense [v28.0](https://typesense.org/docs/28.0/api)\n* Removed deprecated functions in `OpenApiTypesense.Client`\n* Bump dependency versions.\n* Renamed `search` to `search_collection` from `Documents` module.","ref":"changelog.html#changed-28"},{"type":"extras","title":"Added - Changelog","doc":"* Tests for [stemming](https://typesense.org/docs/28.0/api/stemming.html)\n* Doc version tags","ref":"changelog.html#added"},{"type":"extras","title":"0.6.5 (2025.03.23) - Changelog","doc":"","ref":"changelog.html#0-6-5-2025-03-23"},{"type":"extras","title":"Changed (#25) - Changelog","doc":"* the client now accepts all options defined in Req.new/1\n* global configuration can be set in config.exs\n* per-function call overrides are possible using the req argument\n* the Req client configuration has been deprecated and moved from the Client module to the Connection module","ref":"changelog.html#changed-25"},{"type":"extras","title":"0.6.4 (2025.02.16) - Changelog","doc":"","ref":"changelog.html#0-6-4-2025-02-16"},{"type":"extras","title":"Added - Changelog","doc":"* Separate dev and test environments.\n* JOINs tests.","ref":"changelog.html#added-1"},{"type":"extras","title":"Changed - Changelog","doc":"* No timeouts during tests.\n* Bump dependency versions.","ref":"changelog.html#changed-1"},{"type":"extras","title":"0.6.3 (2025.01.30) - Changelog","doc":"","ref":"changelog.html#0-6-3-2025-01-30"},{"type":"extras","title":"Removed - Changelog","doc":"* Logic for checking environment during test.","ref":"changelog.html#removed"},{"type":"extras","title":"0.6.2 (2025.01.26) - Changelog","doc":"","ref":"changelog.html#0-6-2-2025-01-26"},{"type":"extras","title":"Added - Changelog","doc":"* Tests for [JOIns](https://typesense.org/docs/latest/api/joins.html)","ref":"changelog.html#added-2"},{"type":"extras","title":"Changed - Changelog","doc":"* Handle unknown HTTP status response\n* Use [`config_env/0`](https://hexdocs.pm/elixir/Config.html#config_env/0) instead of [`Mix.env/0`](https://hexdocs.pm/mix/Mix.html#env/0)","ref":"changelog.html#changed-2"},{"type":"extras","title":"0.6.1 (2025.01.19) - Changelog","doc":"","ref":"changelog.html#0-6-1-2025-01-19"},{"type":"extras","title":"Added - Changelog","doc":"* `401` status code for unauthorized access","ref":"changelog.html#added-3"},{"type":"extras","title":"0.6.0 (2025.01.19) - Changelog","doc":"","ref":"changelog.html#0-6-0-2025-01-19"},{"type":"extras","title":"Changed - Changelog","doc":"* CI to support Typesense versions v26.0, v27.0, v27.1","ref":"changelog.html#changed-3"},{"type":"extras","title":"Removed - Changelog","doc":"* Support for Typesense version v0.25.2","ref":"changelog.html#removed-1"},{"type":"extras","title":"0.5.2 (2025.01.16) - Changelog","doc":"","ref":"changelog.html#0-5-2-2025-01-16"},{"type":"extras","title":"Changed - Changelog","doc":"* Documentation typos\n* Tidy documentation flow","ref":"changelog.html#changed-4"},{"type":"extras","title":"Added - Changelog","doc":"* Error status code missing from creating a snapshot\n* More test coverage","ref":"changelog.html#added-4"},{"type":"extras","title":"0.5.1 (2025.01.12) - Changelog","doc":"","ref":"changelog.html#0-5-1-2025-01-12"},{"type":"extras","title":"Removed - Changelog","doc":"* `filter_by` option from `Documents.update_document`.","ref":"changelog.html#removed-2"},{"type":"extras","title":"0.5.0 (2025.01.08) - Changelog","doc":"","ref":"changelog.html#0-5-0-2025-01-08"},{"type":"extras","title":"Added - Changelog","doc":"* User(s) can use another HTTP client instead of default ([Req](https://hexdocs.pm/req)).","ref":"changelog.html#added-5"},{"type":"extras","title":"Changed - Changelog","doc":"* Update docs\n* Static to Dynamic fetching of application name for connection defaults.\n* Update docs and include few anchor links.\n* Update specific test where async is disabled when using [`Application.put_env/4`](https://elixirforum.com/t/using-application-get-env-application-put-env-in-exunit-tests/8019/2)","ref":"changelog.html#changed-5"},{"type":"extras","title":"0.4.3 (2024.12.27) - Changelog","doc":"","ref":"changelog.html#0-4-3-2024-12-27"},{"type":"extras","title":"Changed - Changelog","doc":"* Formatting `open_api.yml` file.\n* Bump `ex_doc`\n* Typo in `:oapi_generator` config for dev environment.","ref":"changelog.html#changed-6"},{"type":"extras","title":"0.4.2 (2024.12.22) - Changelog","doc":"","ref":"changelog.html#0-4-2-2024-12-22"},{"type":"extras","title":"Added - Changelog","doc":"* More tests for coverage\n* Options for some functions\n* Endpoints, params for `priv/open_api.yml`","ref":"changelog.html#added-6"},{"type":"extras","title":"0.4.1 (2024.12.19) - Changelog","doc":"","ref":"changelog.html#0-4-1-2024-12-19"},{"type":"extras","title":"Changed - Changelog","doc":"* Disable protocol consolidation during dev or test (for `mix docs`).","ref":"changelog.html#changed-7"},{"type":"extras","title":"0.4.0 (2024.12.17) - Changelog","doc":"","ref":"changelog.html#0-4-0-2024-12-17"},{"type":"extras","title":"Changed - Changelog","doc":"* Typespecs for each functions","ref":"changelog.html#changed-8"},{"type":"extras","title":"0.3.0 (2024.12.15) - Changelog","doc":"","ref":"changelog.html#0-3-0-2024-12-15"},{"type":"extras","title":"Changed - Changelog","doc":"* HTTP request construction in `OpenApiTypesense.Client` to include `options`.","ref":"changelog.html#changed-9"},{"type":"extras","title":"Added - Changelog","doc":"* `options` in config `config/config.exs`.\n* `get_options/0` function in `Client` to fetch the `options` configuration.\n* tests for `get_options/0` in `ClientTest`.","ref":"changelog.html#added-7"},{"type":"extras","title":"0.2.1 (2024.12.15) - Changelog","doc":"","ref":"changelog.html#0-2-1-2024-12-15"},{"type":"extras","title":"Changed - Changelog","doc":"* Update consistency in docs","ref":"changelog.html#changed-10"},{"type":"extras","title":"0.2.0 (2024.12.14) - Changelog","doc":"","ref":"changelog.html#0-2-0-2024-12-14"},{"type":"extras","title":"Changed - Changelog","doc":"* Bumped dependencies","ref":"changelog.html#changed-11"},{"type":"extras","title":"Added - Changelog","doc":"* Default client, currently using [`Req`](https://hexdocs.pm/req).\n* `Connection` module, which is taken from [`ExTypesense`](https://hexdocs.pm/ex_typesense) because someone requested for loading of credentials at runtime.\n* `defstruct` in Modules `Debug`, `Documents` and `Stopwords` because it is throwing undefined struct error.\n* Few descriptions in `priv/open_api.yml` for 4XX response.","ref":"changelog.html#added-8"},{"type":"extras","title":"0.1.0 (2024.11.08) - Changelog","doc":"* Initial release","ref":"changelog.html#0-1-0-2024-11-08"},{"type":"extras","title":"OpenApiTypesense","doc":"# OpenApiTypesense\n\nRestful client for Typesense with adherence to Open API spec 3 (formerly Swagger)\n\n[![Hex.pm](https://img.shields.io/hexpm/v/open_api_typesense)](https://hex.pm/packages/open_api_typesense)\n[![Hexdocs.pm](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/open_api_typesense)\n[![Coverage Status](https://coveralls.io/repos/github/jaeyson/open_api_typesense/badge.svg?branch=main)](https://coveralls.io/github/jaeyson/open_api_typesense?branch=main)\n[![Codacy Badge](https://app.codacy.com/project/badge/Grade/965dd3f8866d49c3b3e82edd0f6270cb)](https://app.codacy.com/gh/jaeyson/open_api_typesense/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)\n[![codescenene Average Code Health](https://codescene.io/projects/63240/status-badges/average-code-health)](https://codescene.io/projects/63240)\n\n[![CI v28.0](https://github.com/jaeyson/open_api_typesense/actions/workflows/ci_v28.0.yml/badge.svg)](https://github.com/jaeyson/open_api_typesense/actions/workflows/ci_v28.0.yml)\n[![CI v27.1](https://github.com/jaeyson/open_api_typesense/actions/workflows/ci_v27.1.yml/badge.svg)](https://github.com/jaeyson/open_api_typesense/actions/workflows/ci_v27.1.yml)\n[![CI v27.0](https://github.com/jaeyson/open_api_typesense/actions/workflows/ci_v27.0.yml/badge.svg)](https://github.com/jaeyson/open_api_typesense/actions/workflows/ci_v27.0.yml)\n[![CI v26.0](https://github.com/jaeyson/open_api_typesense/actions/workflows/ci_v26.0.yml/badge.svg)](https://github.com/jaeyson/open_api_typesense/actions/workflows/ci_v26.0.yml)\n\n[![Dependabot](https://img.shields.io/badge/Dependabot-enabled-green)](https://github.com/jaeyson/open_api_typesense/pulls/app%2Fdependabot)\n[![Hex.pm](https://img.shields.io/hexpm/l/open_api_typesense)](https://hexdocs.pm/open_api_typesense/license.html)\n[![Latest Typesense compatible](https://img.shields.io/badge/Latest%20Typesense%20compatible-v28.0-%230F35BC)](https://typesense.org/docs/28.0/api)\n\n> #### Upgrading to v1 {: .warning}\n>\n> The breaking change here is `conn` is now part of `opts`\n> when calling functions, see example below:\n\n```elixir\n# pre-v1\nCollections.get_collections(conn, opts)\n\n# v1\nCollections.get_collections(conn: conn)\n\n# another way (v1)\nopts = [limit: 1, conn: conn]\nCollections.get_collections(opts)\n```","ref":"readme.html"},{"type":"extras","title":"Installation - OpenApiTypesense","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `open_api_typesense` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:open_api_typesense, \"~> 1.0\"}\n\n    # Or from GitHub repository, if you want the latest greatest from main branch\n    {:open_api_typesense, git: \"https://github.com/jaeyson/open_api_typesense.git\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Getting started - OpenApiTypesense","doc":"","ref":"readme.html#getting-started"},{"type":"extras","title":"Adding credentials - OpenApiTypesense","doc":"Spin up local Typesense instance\n\n```bash\ndocker compose up -d\n\n# check if \"peer refreshed\" in logs\ndocker container logs --follow --tail 50 typesense\n```\n\n```elixir\n# e.g. config/runtime.exs\nif config_env() == :prod do # if you'll use this in prod environment\n  config :open_api_typesense,\n    api_key: \"xyz\",\n    host: \"localhost\",\n    port: 8108,\n    scheme: \"http\"\n  ...\n```\n\n> #### `options` key {: .tip}\n>\n> The `options` key can be used to pass additional configuration\n> options such as custom Finch instance or receive timeout\n> settings. You can add any options supported by Req here. For\n> more details check [Req documentation](https://hexdocs.pm/req/Req.Steps.html#run_finch/1-request-options).\n\n```\nconfig :open_api_typesense,\n  api_key: \"credential\", # Admin API key\n  host: \"111222333aaabbbcc-9.x9.typesense.net\", # Nodes\n  port: 443,\n  scheme: \"https\"\n  options: [finch: MyApp.CustomFinch] # <- add options\n```\n\n> #### during tests {: .tip}\n>\n> If you have a different config for your app, consider \n> adding it in `config/test.exs`.\n\n\nFor Cloud hosted, you can generate and obtain the credentials from cluster instance admin interface:\n\n```elixir\nconfig :open_api_typesense,\n  api_key: \"credential\", # Admin API key\n  host: \"111222333aaabbbcc-9.x9.typesense.net\", # Nodes\n  port: 443,\n  scheme: \"https\"\n```","ref":"readme.html#adding-credentials"},{"type":"extras","title":"Using another connection via maps - OpenApiTypesense","doc":"You might be using a connection that changes dynamically. You can pass it as a map:\n\n```elixir\ncustom_conn = %{api_key: \"xyz\", host: \"localhost\", port: 8108, scheme: \"http\"}\nOpenApiTypesense.Health(conn: conn)\n```","ref":"readme.html#using-another-connection-via-maps"},{"type":"extras","title":"Using another HTTP client - OpenApiTypesense","doc":"In order to use another HTTP client, OpenApiTypesense has a\ncallback function ([Behaviours](https://hexdocs.pm/elixir/typespecs.html#behaviours))\ncalled `request` that contains 2 args:\n\n1. `conn`: your connection map\n2. `params`: payload, header, and client-related stuffs.\n\n> #### `conn` and `params` {: .info}\n>\n> you can change the name `conn` and/or `params` however you want,\n> since it's just a variable.\n\nHere's a custom client example ([`HTTPoison`](https://hexdocs.pm/httpoison/readme.html))\nin order to match the usage:\n\n<!-- tabs-open -->","ref":"readme.html#using-another-http-client"},{"type":"extras","title":"Client module - OpenApiTypesense","doc":"```elixir\ndefmodule MyApp.CustomClient do\n  @behaviour OpenApiTypesense.Client\n  \n  @impl OpenApiTypesense.Client\n  def request(conn, params) do\n    url = %URI{\n      scheme: conn.scheme,\n      host: conn.host,\n      port: conn.port,\n      path: params.url,\n      query: URI.encode_query(params[:query] || %{})\n    }\n    |> URI.to_string()\n\n    request = %HTTPoison.Request{method: params.method, url: url}\n\n    request =\n      if params[:request] do\n        [{content_type, _schema}] = params.request\n\n        headers = [\n          {\"X-TYPESENSE-API-KEY\", conn.api_key}\n          {\"Content-Type\", content_type}\n        ]\n\n        %{request | headers: headers}\n      else\n        request\n      end\n\n    request =\n      if params[:body] do\n        %{request | body: Jason.encode!(params.body)}\n      else\n        request\n      end\n\n    HTTPoison.request!(request)\n  end\nend\n```","ref":"readme.html#client-module"},{"type":"extras","title":"Client config - OpenApiTypesense","doc":"```elixir\nconfig :open_api_typesense,\n  api_key: \"xyz\", # Admin API key\n  host: \"localhost\", # Nodes\n  port: 8108,\n  scheme: \"http\",\n  client: MyApp.CustomClient # <- add this\n```\n\n<!-- tabs-close -->\n\nCheck [the examples](./guides/custom_http_client.md) on some HTTP client implementations.","ref":"readme.html#client-config"},{"type":"extras","title":"Adding cache, retry, compress_body in the built in client - OpenApiTypesense","doc":"E.g. when a user wants to change `retry` and `cache` options\n\n```elixir\nExTypesense.get_collection(\"companies\", req: [retry: false, cache: true])\n```\n\nSee implementation [OpenApiTypesense.Client](`OpenApiTypesense.Client`) https://github.com/jaeyson/open_api_typesense/blob/main/lib/open_api_typesense/client.ex","ref":"readme.html#adding-cache-retry-compress_body-in-the-built-in-client"},{"type":"extras","title":"License","doc":"# MIT License\n\nCopyright (c) 2024 Jaeyson Anthony Y.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE","ref":"license.html"},{"type":"extras","title":"Custom HTTP Client","doc":"# Examples on using a custom HTTP client\n\n> #### Add first the client name in config {: .info}\n>\n> Don't forget to add the client name!\n\n```elixir\nconfig :open_api_typesense,\n  api_key: \"credential\", # Admin API key\n  host: \"111222333aaabbbcc-9.x9.typesense.net\", # Nodes\n  port: 443,\n  scheme: \"https\",\n  client: MyApp.CustomClient # <- this line\n```\n\n## [`:httpc`](https://www.erlang.org/doc/apps/inets/httpc.html)\n\n```elixir\ndefmodule CustomClient do\n  @behaviour OpenApiTypesense.Client\n  \n  @impl OpenApiTypesense.Client\n  def request(conn, params) do\n    uri =\n      %URI{\n        scheme: conn.scheme,\n        host: conn.host,\n        port: conn.port,\n        path: params.url,\n        query: URI.encode_query(params[:query] || %{})\n      }\n      |> URI.to_string()\n\n    headers = [{\"x-typesense-api-key\", conn.api_key}]\n\n    request =\n      if params[:request] do\n        [{content_type, _schema}] = params.request\n        body = Jason.encode!(params[:body] || %{})\n\n        {\n          String.to_charlist(uri),\n          Enum.map(headers, &to_charlist_tuple/1),\n          String.to_charlist(content_type),\n          body\n        }\n      else\n        {\n          String.to_charlist(uri),\n          Enum.map(headers, &to_charlist_tuple/1)\n        }\n      end\n\n    case :httpc.request(params.method, request, [], []) do\n      {:ok, {{_http_version, status_code, _status_message}, response_headers, body}} ->\n        handle_response(status_code, response_headers, body)\n\n      {:error, reason} ->\n        Logger.error(\"HTTP request failed: #{inspect(reason)}\")\n        {:error, reason}\n    end\n  end\n\n  defp handle_response(status_code, _headers, body) when status_code in 200..299 do\n    case Jason.decode(body) do\n      {:ok, decoded_body} ->\n        {:ok, decoded_body}\n\n      {:error, decode_error} ->\n        Logger.error(\"Failed to decode JSON response: #{inspect(decode_error)}\")\n        {:error, :invalid_json}\n    end\n  end\n\n  defp handle_response(status_code, _headers, body) do\n    Logger.warn(\"Request failed with status #{status_code} and body: #{body}\")\n    {:error, %{status: status_code, body: body}}\n  end\n\n  defp to_charlist_tuple({key, value}) do\n    {String.to_charlist(key), String.to_charlist(value)}\n  end\nend\n```\n\n## [HTTPoison](https://hexdocs.pm/httpoison/readme.html)\n\n```elixir\ndefmodule MyApp.CustomClient do\n  @behaviour OpenApiTypesense.Client\n  \n  @impl OpenApiTypesense.Client\n  def request(conn, params) do\n    url = %URI{\n      scheme: conn.scheme,\n      host: conn.host,\n      port: conn.port,\n      path: params.url,\n      query: URI.encode_query(params[:query] || %{})\n    }\n    |> URI.to_string()\n\n    request = %HTTPoison.Request{method: params.method, url: url}\n\n    request =\n      if params[:request] do\n        [{content_type, _schema}] = params.request\n\n        headers = [\n          {\"X-TYPESENSE-API-KEY\", conn.api_key}\n          {\"Content-Type\", content_type}\n        ]\n\n        %{request | headers: headers}\n      else\n        request\n      end\n\n    request =\n      if params[:body] do\n        %{request | body: Jason.encode!(params.body)}\n      else\n        request\n      end\n\n    HTTPoison.request!(request)\n  end\nend\n```\n\n## [`:hackney`](https://hexdocs.pm/hackney)\n\n```elixir\ndefmodule MyApp.CustomClient do\n  @behaviour OpenApiTypesense.Client\n  \n  @impl OpenApiTypesense.Client\n  def request(conn, params) do\n    url = %URI{\n      scheme: conn.scheme,\n      host: conn.host,\n      port: conn.port,\n      path: params.url,\n      query: URI.encode_query(params[:query] || %{})\n    }\n    |> URI.to_string()\n\n    headers =\n      if params[:request] do\n        [{content_type, _schema}] = params.request\n        [\n          {\"x-typesense-api-key\", conn.api_key},\n          {\"content-type\", content_type}\n        ]\n      else\n        [{\"x-typesense-api-key\", conn.api_key}]\n      end\n\n    body = Jason.encode!(params[:body])\n\n    case :hackney.request(params.method, url, headers, body, []) do\n      {:ok, status, _headers, ref} when status in 200..299 ->\n        {:ok, body} = :hackney.body(ref)\n        Jason.decode(body)\n\n      {:ok, status, _headers, ref} ->\n        {:ok, body} = :hackney.body(ref)\n        {:error, %{status: status, body: body}}\n\n      {:error, reason} ->\n        {:error, reason}\n    end\n  end\nend\n```\n\n## [Mint](https://hexdocs.pm/mint)\n\n```elixir\ndefmodule MyApp.CustomClient do\n  @behaviour OpenApiTypesense.Client\n  \n  @impl OpenApiTypesense.Client\n  def request(conn, params) do\n    url = %URI{\n      scheme: conn.scheme,\n      host: conn.host,\n      port: conn.port,\n      path: params.url,\n      query: URI.encode_query(params[:query] || %{})\n    }\n    |> URI.to_string()\n\n    headers =\n      if params[:request] do\n        [{content_type, _schema}] = params.request\n        [\n          {\"x-typesense-api-key\", conn.api_key},\n          {\"content-type\", content_type}\n        ]\n      else\n        [{\"x-typesense-api-key\", conn.api_key}]\n      end\n\n    body = Jason.encode!(params[:body])\n\n    # Start the connection\n    with {:ok, conn} <- Mint.HTTP.connect(String.to_atom(conn.scheme), conn.host, conn.port),\n         {:ok, conn, request_ref} <- Mint.HTTP.request(conn, to_string(params.method), url, headers, body),\n         {:ok, _conn, responses} <- receive_responses(conn, []) do\n      # Find the response associated with the request_ref\n      case Enum.find(responses, fn\n             {:status, ^request_ref, _} -> true\n             _ -> false\n           end) do\n        {:status, ^request_ref, status} when status in 200..299 ->\n          {:ok, body} = parse_body(responses, request_ref)\n          Jason.decode(body)\n\n        {:status, ^request_ref, status} ->\n          {:ok, body} = parse_body(responses, request_ref)\n          {:error, %{status: status, body: body}}\n\n        _ ->\n          {:error, \"No response found\"}\n      end\n    else\n      {:error, reason} -> {:error, reason}\n    end\n  end\n\n  # Helper to receive responses\n  defp receive_responses(conn, acc) do\n    receive do\n      message ->\n        case Mint.HTTP.stream(conn, message) do\n          :unknown ->\n            {:ok, conn, acc}\n\n          {:ok, conn, responses} ->\n            receive_responses(conn, acc ++ responses)\n\n          {:error, conn, reason, _responses} ->\n            {:error, reason}\n        end\n    after\n      5_000 ->\n        {:ok, conn, acc}\n    end\n  end\n\n  # Helper to parse the body\n  defp parse_body(responses, request_ref) do\n    body_chunks =\n      Enum.reduce(responses, [], fn\n        {:data, ^request_ref, chunk}, acc -> [chunk | acc]\n        _, acc -> acc\n      end)\n\n    {:ok, IO.iodata_to_binary(Enum.reverse(body_chunks))}\n  end\nend\n```\n\n## [Finch](https://hexdocs.pm/finch)\n\n<!-- tabs-open -->","ref":"custom_http_client.html"},{"type":"extras","title":"Client - Custom HTTP Client","doc":"```elixir\ndefmodule MyApp.CustomClient do\n  @behaviour OpenApiTypesense.Client\n  \n  @impl OpenApiTypesense.Client\n  def request(conn, _params) do\n    uri = %URI{\n      scheme: conn.scheme,\n      host: conn.host,\n      port: conn.port,\n      path: params.url,\n      query: URI.encode_query(params[:query] || %{})\n    }\n    |> URI.to_string()\n\n    [{content_type, _schema}] = params.request\n\n    headers =\n      if params[:request] do\n        [{content_type, _schema}] = params.request\n        [\n          {\"x-typesense-api-key\", conn.api_key},\n          {\"content-type\", content_type}\n        ]\n      else\n        [{\"x-typesense-api-key\", conn.api_key}]\n      end\n\n    body = Jason.encode!(params[:body])\n\n    # Perform the request using Finch\n    case Finch.build(:put, url, headers, body)\n         |> Finch.request(MyFinch) do\n      {:ok, %Finch.Response{status: status, body: body}} when status in 200..299 ->\n        Jason.decode(body)\n\n      {:ok, %Finch.Response{status: status, body: body}} ->\n        {:error, %{status: status, body: body}}\n\n      {:error, reason} ->\n        {:error, reason}\n    end\n  end\nend\n```\n\n### `application.ex`\n\nAdd to your supervision tree:\n\n```elixir\n# e.g. lib/my_app/application.ex\n  @impl true\n  def start(_type, _args) do\n    children = [\n      # Starts a worker by calling: Githubber.Worker.start_link(arg)\n      # {Githubber.Worker, arg}\n      {Finch, name: MyFinch} # <- add this\n    ]\n\n    # See https://hexdocs.pm/elixir/Supervisor.html\n    # for other strategies and supported options\n    opts = [strategy: :one_for_one, name: Githubber.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n```\n\n<!-- tabs-close -->\n\n## [Tesla](https://hexdocs.pm/tesla)\n\n<!-- tabs-open -->","ref":"custom_http_client.html#client"},{"type":"extras","title":"Adapter - Custom HTTP Client","doc":"```elixir\n# e.g. config/config.exs\nimport Config\n\nconfig :tesla, adapter: Tesla.Adapter.Hackney\n```","ref":"custom_http_client.html#adapter"},{"type":"extras","title":"Config - Custom HTTP Client","doc":"```elixir\n# e.g. config/runtime.exs\nconfig :open_api_typesense,\n  api_key: \"xyz\",\n  host: \"localhost\",\n  port: 8108,\n  scheme: \"http\",\n  client: MyApp.CustomClient\n```","ref":"custom_http_client.html#config"},{"type":"extras","title":"Client - Custom HTTP Client","doc":"```elixir\ndefmodule MyApp.CustomClient do\n  @behaviour OpenApiTypesense.Client\n  \n  @impl OpenApiTypesense.Client\n  def request(conn, params) do\n    url =\n      %URI{\n        scheme: conn.scheme,\n        host: conn.host,\n        port: conn.port,\n        path: params.url\n      }\n      |> URI.to_string()\n\n    body = Jason.encode!(params[:body])\n\n    options = [\n      method: params.method,\n      url: url,\n      query: params[:query],\n      body: body\n    ]\n\n    headers =\n      if params[:request] do\n        [{content_type, _schema}] = params.request\n        [\n          {\"x-typesense-api-key\", conn.api_key},\n          {\"content-type\", content_type}\n        ]\n      else\n        [{\"x-typesense-api-key\", conn.api_key}]\n      end\n\n    client =\n      Tesla.client([\n        {Tesla.Middleware.Headers, headers},\n        Tesla.Middleware.JSON\n      ])\n\n    case Tesla.request(client, options) do\n      {:ok, %Tesla.Env{status: status, body: body}} when status in 200..299 ->\n        {:ok, body}\n\n      {:ok, %Tesla.Env{status: status, body: body}} ->\n        {:error, %{status: status, body: body}}\n\n      {:error, reason} ->\n        {:error, reason}\n    end\n  end\nend\n```\n\n<!-- tabs-close -->\n\n## [`:gun`](https://hexdocs.pm/gun)\n\n```elixir\ndefmodule MyApp.CustomClient do\n  @behaviour OpenApiTypesense.Client\n  \n  @impl OpenApiTypesense.Client\n  def request(conn, params) do\n    # Open a connection\n    {:ok, pid} =\n      :gun.open(String.to_charlist(conn.host), conn.port, %{\n        protocols: [:http],\n        transport: if(conn.scheme == \"https\", do: :tls, else: :tcp)\n      })\n\n    # Await the connection\n    {:ok, _protocol} = :gun.await_up(pid)\n\n    url = params.url <> URI.encode_query(params[:query] || %{})\n\n    headers =\n      if params[:request] do\n        [{content_type, _schema}] = params[:request]\n\n        [\n          {\"x-typesense-api-key\", conn.api_key},\n          {\"content-type\", content_type}\n        ]\n      else\n        [{\"x-typesense-api-key\", conn.api_key}]\n      end\n\n    body = Jason.encode!(params[:body])\n\n    # Make the PUT request\n    # stream_ref = :gun.put(pid, url, headers, body)\n    stream_ref =\n      case params.method do\n        :get -> :gun.get(pid, url, headers)\n        :post -> :gun.post(pid, url, headers, body)\n        :put -> :gun.put(pid, url, headers, body)\n        :delete -> :gun.delete(pid, url, headers)\n        :patch -> :gun.patch(pid, url, headers, body)\n      end\n\n    # Await the response\n    case :gun.await(pid, stream_ref) do\n      {:response, :fin, status, headers} ->\n        # Handle response with no body\n        :gun.close(pid)\n        {:ok, {status, headers, \"\"}}\n\n      {:response, :nofin, status, headers} ->\n        # Handle response with body\n        {:ok, body} = receive_body(pid, stream_ref)\n        :gun.close(pid)\n\n        # Parse the JSON response if content-type is application/json\n        content_type =\n          headers\n          |> Enum.find(fn {key, _} -> String.downcase(key) == \"content-type\" end)\n          |> elem(1)\n\n        body =\n          if String.contains?(content_type, \"application/json\") do\n            case Jason.decode(body) do\n              {:ok, decoded} -> decoded\n              {:error, _} -> body\n            end\n          else\n            body\n          end\n\n        {:ok, {status, headers, body}}\n\n      {:error, _} = error ->\n        :gun.close(pid)\n        error\n    end\n  end\n\n  # Helper function to receive the complete response body\n  defp receive_body(pid, stream_ref, acc \\\\ \"\") do\n    receive do\n      {:gun_data, ^pid, ^stream_ref, :fin, data} ->\n        {:ok, acc <> data}\n\n      {:gun_data, ^pid, ^stream_ref, :nofin, data} ->\n        receive_body(pid, stream_ref, acc <> data)\n\n      {:gun_error, ^pid, ^stream_ref, reason} ->\n        {:error, reason}\n\n      {:gun_down, ^pid, _, _, _, _} ->\n        {:error, :connection_down}\n    after\n      5_000 ->\n        {:error, :timeout}\n    end\n  end\nend\n```","ref":"custom_http_client.html#client-1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}